.. py:module:: bcdi.algorithms

.. toctree::
   :maxdepth: 2

:mod:`bcdi.algorithms`: Image and PSF deconvolution using Richardson-Lucy algorithm
===================================================================================

algorithms_utils
^^^^^^^^^^^^^^^^

This module includes routines using Richardson-Lucy deconvolution algorithm and blind
deconvolution, that can be applied to a 3D dataset.

API Reference
-------------

.. automodule:: bcdi.algorithms.algorithms_utils
   :members:
